==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/NativeUILabel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUILabel = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUILabel, _super);
    function NativeUILabel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUILabel.prototype.get_e = function () {
        return 3;
    };
    Object.defineProperty(NativeUILabel.prototype, "az", {
        get: function () {
            var a = this.q(8);
            return a;
        },
        set: function (a) {
            this.ak(8, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUILabel.prototype, "ay", {
        get: function () {
            var a = this.q(9);
            return a;
        },
        set: function (a) {
            this.ak(9, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUILabel.$t = markType(NativeUILabel, 'NativeUILabel', NativeUIComponent.$);
    return NativeUILabel;
}(NativeUIComponent));
export { NativeUILabel };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/NativeUILabel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUILabel = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUILabel, _super);
    function NativeUILabel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUILabel.prototype.get_e = function () {
        return 3;
    };
    Object.defineProperty(NativeUILabel.prototype, "bm", {
        get: function () {
            var a = this.ag(10);
            return a;
        },
        set: function (a) {
            this.a4(10, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUILabel.prototype, "bk", {
        get: function () {
            var a = this.ag(11);
            return a;
        },
        set: function (a) {
            this.a4(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUILabel.prototype, "bl", {
        get: function () {
            return this.ag(31);
        },
        set: function (a) {
            this.a4(31, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUILabel.$t = markType(NativeUILabel, 'NativeUILabel', NativeUIComponent.$);
    return NativeUILabel;
}(NativeUIComponent));
export { NativeUILabel };
